@@ -63,6 +63,8 @@ class Document(OrderedClass):
         self.tokens = tokens
         self.raw_detokens = None
         self.summary = None
+        self.summary_short = None
+        self.summary_short_bullet = None
         self.summary_detokens = {}
         self.compressed_summary = None
         self.compressed_summary_detokens = {}
@@ -205,8 +207,10 @@ class Sentence(OrderedClass):
         self.truecase_sentence = None
         self.detruecase_sentence = None
 
+        self.speech_acts_legacy = None
+        self.speech_act_values_legacy = None
+
         self.speech_acts = None
-        self.speech_act_values = None
         self.question_types = None
         self.question_tags = None
 
@@ -303,6 +307,9 @@ class CodeqClient(object):
     def lemma(self, text, sentences):
         return self.__run_request(text, sentences, pipeline='lemma')
 
+    def speechact_legacy(self, text, sentences):
+        return self.__run_request(text, sentences, pipeline='speechact_legacy')
+
     def speechact(self, text, sentences):
         return self.__run_request(text, sentences, pipeline='speechact')
 
